@@ -13,7 +13,7 @@ use Mojo::Util qw(b64_encode dumper);
 use Mojo::Log;
 use Carp;
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 has log => sub ($self) {
     Mojo::Log->new;
@@ -117,6 +117,9 @@ sub call_p ($self,$operation,$params={}) {
         operation => $operation,
         transport => $self->transport,
         async => 1,
+        # oddly repetitive, the port is mentioned in the endPoint
+        # selection as well as here ... 
+        ( $self->port ? ( port => $self->port ) : () ),
     );
     $self->log->debug(__PACKAGE__ . " $operation called");
     return Mojo::Promise->new(sub ($resolve,$reject) {
